@@ -1,16 +1,15 @@
 use strict;
-use warning;
 package Event::tcpserv;
 use Carp;
 use Symbol;
 use Socket;
 use Fcntl;
-use Event 0.40;
+use Event 0.50;
 use Event::Watcher qw(R W T);
 require Event::io;
-use vars qw($VERSION @ISA);
+use base 'Event::io';
+use vars qw($VERSION);
 $VERSION = '0.06';
-@ISA = 'Event::io';
 
 'Event::Watcher'->register;
 
@@ -18,9 +17,9 @@ sub new {
     my $class = shift;
     my %arg = @_;
 
-    my $port = delete $arg{e_port} || die "e_port required";
-    my $cb = delete $arg{e_cb} || die "e_cb required";
-    for (qw(e_fd e_poll)) { carp "$_ ignored" if delete $arg{$_}; }
+    my $port = delete $arg{port} || die "port required";
+    my $cb = delete $arg{cb} || die "cb required";
+    for (qw(fd poll)) { carp "$_ ignored" if delete $arg{$_}; }
 
     my $proto = getprotobyname('tcp');
     socket(my $sock = gensym, PF_INET, SOCK_STREAM, $proto)
@@ -30,18 +29,12 @@ sub new {
     bind($sock, sockaddr_in($port, INADDR_ANY)) or die "bind: $!";
     listen($sock, SOMAXCONN)                    or die "listen: $!";
 
-    $class->SUPER::new(%arg, e_fd => $sock, e_poll => R, e_reentrant => 0,
-		       e_max_cb_tm => 5, e_cb => sub {
+    $class->SUPER::new(%arg, fd => $sock, poll => R, reentrant => 0,
+		       max_cb_tm => 5, cb => sub {
 			   my ($e) = @_;
 			   my $w=$e->w;
 			   my $sock = gensym;
-			   accept $sock, $w->{e_fd} or return;
-	       # fcntl might be architecture dependent XXX
-	       #my $fcntl = pack 'I', O_NONBLOCK | O_NDELAY;
-	       #warn join(' ', unpack 'c*', $fcntl);
-	       #fcntl $sock, F_SETFL, $fcntl or die "fcntl SETFL $!";
-	       #fcntl $sock, F_GETFL, $fcntl or die "fcntl GETFL $!";
-	       #warn join(' ', unpack 'c*', $fcntl);
+			   accept $sock, $w->fd or return;
 			   $cb->($w, $sock);
 		       });
 }
@@ -49,6 +42,9 @@ sub new {
 1;
 
 __END__
+
+callback should be something like this:
+
     Event->io(e_desc => $w->{e_desc}.' '.fileno($sock),
 	      e_fd => $sock, e_prio => $e->{e_prio},
 	      e_poll => R, e_reentrant => 0,
